@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file 
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file 
  */
 
 #ifndef __RFC2822_H
@@ -15,7 +15,7 @@
 bool rfc2822_header_field_name_verify
 	(const char *field_name, unsigned int len);
 bool rfc2822_header_field_body_verify
-(const char *field_body, unsigned int len);
+	(const char *field_body, unsigned int len, bool allow_crlf, bool allow_utf8);
 
 /*
  *
@@ -27,6 +27,10 @@ const char *rfc2822_header_field_name_sanitize(const char *name);
  * Message composition
  */
 
+unsigned int rfc2822_header_field_append
+	(string_t *header, const char *name, const char *body, bool crlf,
+		uoff_t *body_offset_r);
+
 int rfc2822_header_field_write
 	(FILE *f, const char *name, const char *body);
 	
