@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_COMMANDS_H
@@ -163,7 +163,7 @@ struct sieve_command {
 	( sieve_command_def_type_name((cmd)->def) )	
 
 #define sieve_commands_equal(cmd1, cmd2) \
-	( (cmd1)->def == (cmd2)->def )
+	( (cmd1) != NULL && (cmd2) != NULL && (cmd1)->def == (cmd2)->def )
 
 /* Context API */
 
@@ -200,6 +200,8 @@ bool sieve_command_block_exits_unconditionally
 
 #define sieve_command_generate_error(gentr, context, ...) \
 	sieve_generator_error(gentr, (context)->ast_node->source_line, __VA_ARGS__)
+#define sieve_command_generate_warning(gentr, context, ...) \
+	sieve_generator_warning(gentr, (context)->ast_node->source_line, __VA_ARGS__)
 
 /* Utility macros */
 
