@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_COMMON_H
@@ -145,7 +145,7 @@ struct sieve_ast *sieve_parse
 		enum sieve_error *error_r);
 bool sieve_validate
 	(struct sieve_ast *ast, struct sieve_error_handler *ehandler,
-		enum sieve_error *error_r);	
+		enum sieve_compile_flags flags, enum sieve_error *error_r);	
 
 /*
  * Sieve engine instance
@@ -155,8 +155,19 @@ struct sieve_instance {
 	/* Main engine pool */
 	pool_t pool;
 
+	/* System environment */
+	const char *hostname;
+	const char *base_dir;
+
+	/* User environment */
+	const char *username;
+	const char *home_dir;
+
+	/* Flags */
+	enum sieve_flag flags;
+
 	/* Callbacks */
-	const struct sieve_environment *env;
+	const struct sieve_callbacks *callbacks;
 	void *context;
 
 	/* Engine debug */
