@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_EXT_ENVIRONMENT_H
@@ -10,7 +10,8 @@ struct sieve_environment_item {
 	const char *name;
 	
 	const char *value;
-	const char *(*get_value)(const struct sieve_script_env *senv);
+	const char *(*get_value)
+		(struct sieve_instance *svinst, const struct sieve_script_env *senv);
 };
 
 void sieve_ext_environment_item_register
