@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file
  */
 
 #ifndef __SIEVE_SETTINGS_H
@@ -13,12 +13,12 @@
 static inline const char *sieve_setting_get
 (struct sieve_instance *svinst, const char *identifier)
 {
-	const struct sieve_environment *env = svinst->env;
+	const struct sieve_callbacks *callbacks = svinst->callbacks;
 
-	if ( env == NULL || env->get_setting == NULL )
+	if ( callbacks == NULL || callbacks->get_setting == NULL )
 		return NULL;
 
-	return env->get_setting(svinst->context, identifier);
+	return callbacks->get_setting(svinst->context, identifier);
 }
 
 bool sieve_setting_get_uint_value
@@ -44,12 +44,15 @@ bool sieve_setting_get_duration_value
 static inline const char *sieve_environment_get_homedir
 (struct sieve_instance *svinst)
 {
-	const struct sieve_environment *env = svinst->env;
+	const struct sieve_callbacks *callbacks = svinst->callbacks;
 
-	if ( env == NULL || env->get_homedir == NULL )
+	if ( svinst->home_dir != NULL )
+		return svinst->home_dir;
+
+	if ( callbacks == NULL || callbacks->get_homedir == NULL )
 		return NULL;
 
-	return env->get_homedir(svinst->context);
+	return callbacks->get_homedir(svinst->context);
 }
 
 #endif /* __SIEVE_SETTINGS_H */
