@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2011 Pigeonhole authors, see the included COPYING file 
+/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file 
  */
  
 #ifndef __SIEVE_VALIDATOR_H
@@ -30,7 +30,8 @@ struct sieve_command_registration;
 struct sieve_validator;
 
 struct sieve_validator *sieve_validator_create
-	(struct sieve_ast *ast, struct sieve_error_handler *ehandler);
+	(struct sieve_ast *ast, struct sieve_error_handler *ehandler,
+		enum sieve_compile_flags flags);
 void sieve_validator_free(struct sieve_validator **valdtr);
 pool_t sieve_validator_pool(struct sieve_validator *valdtr);
 
@@ -48,6 +49,8 @@ struct sieve_script *sieve_validator_script
 	(struct sieve_validator *valdtr);
 struct sieve_instance *sieve_validator_svinst
 	(struct sieve_validator *valdtr);
+enum sieve_compile_flags sieve_validator_compile_flags
+	(struct sieve_validator *valdtr);
 
 /*
  * Error handling
